Documentation
¶
Index ¶
- func Has(ctx context.Context, arg1, arg2 runtime.Value) (runtime.Value, error)
- func KeepKeys(ctx context.Context, args ...runtime.Value) (runtime.Value, error)
- func Keys(ctx context.Context, args ...runtime.Value) (runtime.Value, error)
- func Merge(ctx context.Context, args ...runtime.Value) (runtime.Value, error)
- func MergeRecursive(ctx context.Context, args ...runtime.Value) (runtime.Value, error)
- func RegisterLib(ns runtime.Namespace)
- func Values(ctx context.Context, arg runtime.Value) (runtime.Value, error)
- func Zip(ctx context.Context, arg1, arg2 runtime.Value) (runtime.Value, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Has ¶
HAS returns the value stored by the given key. @param {String} key - The key name string. @return {Boolean} - True if the key exists else false.
func KeepKeys ¶
KEEP_KEYS returns a new object with only given keys. @param {Object|Map} obj - Source object. @param {String, repeated} keys - Keys that need to be kept. @return {Map} - New Object with only given keys.
func Keys ¶
KEYS returns string array of object's keys @param {Map} obj - The object whose keys you want to extract @param {Boolean} [sort=False] - If sort is true, then the returned keys will be sorted. @return {String[]} - arrayList that contains object keys.
func Merge ¶
MERGE merge the given objects into a single object. @param {Map, repeated} objects - Maps to merge. @return {Map} - Map created by merging.
func MergeRecursive ¶
MERGE_RECURSIVE recursively merge the given objects into a single object. @param {Map, repeated} objects - Maps to merge. @return {Map} - Map created by merging.
func RegisterLib ¶
func Values ¶
VALUES return the attribute values of the map as a list. @param {Map} map - Target map. @return {Any[]} - Values of document returned in any order.
func Zip ¶
ZIP returns an object assembled from the separate parameters keys and values. Keys and values must be arrays and have the same length. @param {String[]} keys - An array of strings, to be used as key names in the result. @param {hashMap[]} values - An array of runtime.Value, to be used as key values. @return {Map} - An object with the keys and values assembled.
Types ¶
This section is empty.